@@ -14,14 +14,12 @@ OPTION_5_KEYWORD : :obj:`str`
     Generic string identifier for testing.
 
 """
-
 import re
 
 import pytest
 
 from pyproprop import processed_property
 
-
 OPTION_1_KEYWORD = "option_1"
 OPTION_2_KEYWORD = "option_2"
 OPTION_3_KEYWORD = "option_3"
@@ -36,34 +34,40 @@ class ClassWithOptionProperties:
     ----------
 
     """
+
     one_option_prop = processed_property(
         "one_option_prop",
         description="option property with a single option",
         type=str,
-        options=(OPTION_1_KEYWORD, )
+        str_format="snake",
+        options=(OPTION_1_KEYWORD, ),
     )
     mul_option_prop = processed_property(
         "mul_option_prop",
         description="option property with multiple options",
         type=str,
-        options=(OPTION_1_KEYWORD,
-                 OPTION_2_KEYWORD,
-                 OPTION_3_KEYWORD,
-                 OPTION_4_KEYWORD,
-                 OPTION_5_KEYWORD,
-                 )
+        str_format="snake",
+        options=(
+            OPTION_1_KEYWORD,
+            OPTION_2_KEYWORD,
+            OPTION_3_KEYWORD,
+            OPTION_4_KEYWORD,
+            OPTION_5_KEYWORD,
+        ),
     )
     one_unsupported_option_prop = processed_property(
         "one_unsupported_option_prop",
         description=("option property with multiple options and a single "
                      "unsupported option"),
         type=str,
-        options=(OPTION_1_KEYWORD,
-                 OPTION_2_KEYWORD,
-                 OPTION_3_KEYWORD,
-                 OPTION_4_KEYWORD,
-                 OPTION_5_KEYWORD,
-                 ),
+        str_format="snake",
+        options=(
+            OPTION_1_KEYWORD,
+            OPTION_2_KEYWORD,
+            OPTION_3_KEYWORD,
+            OPTION_4_KEYWORD,
+            OPTION_5_KEYWORD,
+        ),
         unsupported_options=(OPTION_5_KEYWORD, ),
     )
     mul_unsupported_option_prop = processed_property(
@@ -71,24 +75,28 @@ class ClassWithOptionProperties:
         description=("option property with multiple options and multiple "
                      "unsupported options"),
         type=str,
-        options=(OPTION_1_KEYWORD,
-                 OPTION_2_KEYWORD,
-                 OPTION_3_KEYWORD,
-                 OPTION_4_KEYWORD,
-                 OPTION_5_KEYWORD,
-                 ),
-        unsupported_options=(OPTION_3_KEYWORD,
-                             OPTION_4_KEYWORD,
-                             OPTION_5_KEYWORD,
-                             ),
+        str_format="snake",
+        options=(
+            OPTION_1_KEYWORD,
+            OPTION_2_KEYWORD,
+            OPTION_3_KEYWORD,
+            OPTION_4_KEYWORD,
+            OPTION_5_KEYWORD,
+        ),
+        unsupported_options=(
+            OPTION_3_KEYWORD,
+            OPTION_4_KEYWORD,
+            OPTION_5_KEYWORD,
+        ),
     )
 
-    def __init__(self,
-                 one_option=OPTION_1_KEYWORD,
-                 mul_option=OPTION_1_KEYWORD,
-                 one_unsupported_option=OPTION_1_KEYWORD,
-                 mul_unsupported_option=OPTION_1_KEYWORD,
-                 ):
+    def __init__(
+            self,
+            one_option=OPTION_1_KEYWORD,
+            mul_option=OPTION_1_KEYWORD,
+            one_unsupported_option=OPTION_1_KEYWORD,
+            mul_unsupported_option=OPTION_1_KEYWORD,
+    ):
         """Initialise the numerical bounds on the processed properties.
 
         Parameters
@@ -111,6 +119,18 @@ def test_instantiation_class_with_option_properties():
     _ = ClassWithOptionProperties()
 
 
+@pytest.mark.parametrize(
+    "input_str",
+    [
+        "option-1", "Option 1  ", "Option__1", "OpTiOn _-1 -__",
+        "    OPTION_1---"
+    ],
+)
+def test_setting_with_valid_options(test_fixture, input_str):
+    test_fixture.one_option_prop = input_str
+    assert test_fixture.one_option_prop == OPTION_1_KEYWORD
+
+
 def test_single_option_all_unsupported_option():
     """"""
     expected_error_msg = re.escape(
@@ -174,18 +194,20 @@ def test_multiple_option_all_are_unsupported_option():
             mul_all_unsupported_option_prop = processed_property(
                 "mul_all_unsupported_option_prop",
                 type=str,
-                options=(OPTION_1_KEYWORD,
-                         OPTION_2_KEYWORD,
-                         OPTION_3_KEYWORD,
-                         OPTION_4_KEYWORD,
-                         OPTION_5_KEYWORD,
-                         ),
-                unsupported_options=(OPTION_1_KEYWORD,
-                                     OPTION_2_KEYWORD,
-                                     OPTION_3_KEYWORD,
-                                     OPTION_4_KEYWORD,
-                                     OPTION_5_KEYWORD,
-                                     ),
+                options=(
+                    OPTION_1_KEYWORD,
+                    OPTION_2_KEYWORD,
+                    OPTION_3_KEYWORD,
+                    OPTION_4_KEYWORD,
+                    OPTION_5_KEYWORD,
+                ),
+                unsupported_options=(
+                    OPTION_1_KEYWORD,
+                    OPTION_2_KEYWORD,
+                    OPTION_3_KEYWORD,
+                    OPTION_4_KEYWORD,
+                    OPTION_5_KEYWORD,
+                ),
             )
 
 
@@ -204,18 +226,18 @@ def test_raises_value_error_with_invalid_option(test_fixture):
 
 
 def test_option_creation_from_dict_keys():
-
     class ClassWithMultipleOptionAllUnsupportedOptionProperties:
 
         option_from_dict_keys_prop = processed_property(
             "option_from_dict_keys_prop",
             type=str,
-            options={OPTION_1_KEYWORD: None,
-                     OPTION_2_KEYWORD: None,
-                     OPTION_3_KEYWORD: None,
-                     OPTION_4_KEYWORD: None,
-                     OPTION_5_KEYWORD: None,
-                     }.keys(),
+            options={
+                OPTION_1_KEYWORD: None,
+                OPTION_2_KEYWORD: None,
+                OPTION_3_KEYWORD: None,
+                OPTION_4_KEYWORD: None,
+                OPTION_5_KEYWORD: None,
+            }.keys(),
             unsupported_options=(OPTION_5_KEYWORD, ),
         )
 
